/*
 * Copyright (C) 2006 
 * Thomas van Dijk
 * Jan-Pieter van den Heuvel
 * Wouter Slob
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
package libtw.ngraph;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;

public class NVertexOrder< D > {
	
	public NVertexOrder() {
		order = new ArrayList<NVertex<D>>();
	}
	public NVertexOrder( int size ) {
		order = new ArrayList<NVertex<D>>( size );
	}
	public NVertexOrder( NVertexOrder<D> other ) {
		order = new ArrayList<NVertex<D>>( other.order );
	}
	
	public ArrayList<NVertex<D>> order;
	
	public String toString() {
		String s = "";
		for( NVertex<D> v : order) {
			s = s.concat( " " + v.data.toString() );
		}
		return s;
	}
	
	public NVertexOrder<D> copy() {
		
		NVertexOrder<D> newVO = new NVertexOrder<D>();
		
		HashMap<NVertex<D>, NVertex<D>> oldToNew = new HashMap<NVertex<D>, NVertex<D>>();
		
		for( NVertex<D> v : this.order ) {
			NVertex<D> nv = v.newOfSameType( v.data );
			newVO.order.add( nv );
			oldToNew.put( v, nv );
		}
		for( NVertex<D> v : this.order ) {
			for( NVertex<D> n : v ) {
				oldToNew.get(v).addNeighbor(oldToNew.get(n));
			}
		}
		return newVO;
	}
	
	public boolean isEqual(NVertexOrder<D> input){
		Iterator<NVertex<D>> iter1 = this.order.iterator();
		Iterator<NVertex<D>> iter2 = input.order.iterator();
		while(iter1.hasNext()){
			NVertex<D> node1 = iter1.next();
			if(iter2.hasNext()){
				NVertex<D> node2 = iter2.next();
				if(!node1.data.toString().equals(node2.data.toString()))
					return false;
			}
			else return false;
		}
		return true;
	}
}
